From 7aa4d458e9abed2569fe0cc69277d904b94b10fc Mon Sep 17 00:00:00 2001
From: Michael Paquier <michael@otacoo.com>
Date: Tue, 28 Apr 2015 05:53:49 -0700
Subject: [PATCH 2/2] Enable version-specific tests of plpython transforms in
 MSVC

Those tests need to check for the version of Python available on system
in order to select the extensions that should be loaded for the tests.
---
 src/tools/msvc/vcregress.pl | 29 +++++++++++++++++++++++++++--
 1 file changed, 27 insertions(+), 2 deletions(-)

diff --git a/src/tools/msvc/vcregress.pl b/src/tools/msvc/vcregress.pl
index 8c071a5..92798dc 100644
--- a/src/tools/msvc/vcregress.pl
+++ b/src/tools/msvc/vcregress.pl
@@ -244,6 +244,31 @@ sub subdircheck
 	print "Checking $module\n";
 	my @tests = fetchTests();
 	my @opts  = fetchRegressOpts();
+
+	# Add some options for transform modules, see their respective
+	# Makefile for more details regarding Python-version specific
+	# dependencies.
+	if ($module eq "hstore_plpython" ||
+		$module eq "ltree_plpython")
+	{
+		die "Python not enabled in configuration"
+			if !defined($config->{python});
+
+		# Get major version number of Python.
+		open(P,
+			$config->{python}
+			  . "\\python -c \"import sys;print(str(sys.version_info[0]))\" |"
+		) || die "Could not query for python version!\n";
+		my $pyver = <P>;
+		chomp($pyver);
+		close(P);
+		if ($pyver eq "2")
+		{
+			push @opts, "--load-extension=plpythonu";
+			push @opts, '--load-extension=' . $module . 'u';
+		}
+	}
+
 	my @args  = (
 		"${tmp_installdir}/bin/pg_regress",
 		"--bindir=${tmp_installdir}/bin",
@@ -266,8 +291,8 @@ sub contribcheck
 		next if ($module eq "sslinfo"         && !defined($config->{openssl}));
 		next if ($module eq "xml2"            && !defined($config->{xml}));
 		next if ($module eq "hstore_plperl"   && !defined($config->{perl}));
-		next if ($module eq "hstore_plpython");
-		next if ($module eq "ltree_plpython");
+		next if ($module eq "hstore_plpython" && !defined($config->{python}));
+		next if ($module eq "ltree_plpython"  && !defined($config->{python}));
 		next if ($module eq "sepgsql");
 
 		subdircheck("$topdir/contrib", $module);
-- 
2.3.6

